# 📚 Документация OneC Contract Generator

## 📋 Оглавление

### 🚀 Основная документация

- **[README.md](../README.md)** - Главная страница проекта с обзором возможностей
- **[CHANGELOG.md](../CHANGELOG.md)** - История изменений и версий
- **[PUBLISH_GUIDE.md](../PUBLISH_GUIDE.md)** - Руководство по публикации на PyPI

### 📖 Руководства

- **[USAGE.md](USAGE.md)** - Подробное руководство по использованию
  - Установка с PyPI
  - Быстрый старт
  - Параметры командной строки
  - Структура выходных данных
  - Примеры использования
  - Анализ контрактов
  - Группировка логов
  - Устранение проблем
  - Результаты тестирования

- **[EXAMPLES.md](EXAMPLES.md)** - Практические примеры
  - Установка и настройка
  - Примеры команд
  - Примеры контрактов (новая структура)
  - Примеры анализа
  - Примеры логов
  - Примеры тестирования
  - Примеры конфигурации
  - Структура проекта

### 🔧 Техническая документация

- **[API.md](API.md)** - API документация
  - Установка и импорт
  - Обзор API
  - ContractGeneratorLauncher API
  - MetadataGenerator API
  - FormGenerator API
  - ModuleGenerator API
  - Структуры данных (обновленные)
  - Категории объектов
  - Примеры использования
  - Конфигурация

- **[DEVELOPMENT.md](DEVELOPMENT.md)** - Документация для разработчиков
  - Установка для разработки
  - Архитектура системы
  - Основные компоненты
  - Система логирования
  - Тестирование
  - Конфигурация пакета
  - Публикация на PyPI
  - Отладка
  - Разработка новых функций
  - Лучшие практики

## 🎯 Быстрая навигация

### 🚀 Для новых пользователей
1. **[README.md](../README.md)** - Обзор проекта и установка с PyPI
2. **[USAGE.md](USAGE.md)** - Руководство по использованию
3. **[EXAMPLES.md](EXAMPLES.md)** - Примеры использования

### 🔧 Для разработчиков
1. **[DEVELOPMENT.md](DEVELOPMENT.md)** - Архитектура и разработка
2. **[API.md](API.md)** - API документация
3. **[USAGE.md](USAGE.md)** - Детальное руководство

### 🐛 Для решения проблем
1. **[USAGE.md](USAGE.md)** - Раздел "Устранение проблем"
2. **[EXAMPLES.md](EXAMPLES.md)** - Примеры логов и ошибок
3. **[DEVELOPMENT.md](DEVELOPMENT.md)** - Отладка

### 📦 Для публикации
1. **[PUBLISH_GUIDE.md](../PUBLISH_GUIDE.md)** - Полное руководство по PyPI
2. **[DEVELOPMENT.md](DEVELOPMENT.md)** - Раздел "Публикация на PyPI"

## 📊 Статистика документации

- **Общий объем**: ~60KB текста
- **Количество файлов**: 5 основных документов
- **Примеры кода**: 80+ примеров
- **Скриншоты и диаграммы**: Включены в описания
- **Версия пакета**: 2.1.1

## 🔄 Обновления документации

Документация обновляется в соответствии с развитием проекта:

- **v2.1.1** - Публикация на PyPI, обновленная структура контрактов
- **v2.0.0** - Группировка логов, улучшенная обработка ошибок
- **v1.0.0** - Первый релиз с полной документацией
- **v0.9.0** - Восстановление функционала
- **v0.8.0** - Рефакторинг архитектуры

## 🆕 Новые возможности в v2.1.1

### 📦 Публикация на PyPI
- Пакет доступен для установки через `pip install onec-contract-generator`
- Команды командной строки: `onec-contract-generate`, `onec-contract-analyze`, `onec-contract-test`
- Полная поддержка Python 3.7+

### 🔍 Гибридная организация файлов
- Плоская структура с префиксами типов в именах файлов
- Богатая информация для семантического поиска в `search_info`
- Оптимизация для поисковых систем

### 📁 Расширенная поддержка типов объектов
- 40+ поддерживаемых типов объектов 1С
- Автоматическая категоризация объектов
- Улучшенное извлечение кратких имен объектов

### 🛠️ Улучшенная конфигурация
- Современная конфигурация с `pyproject.toml`
- Разделение зависимостей на production и development
- Автоматизированные скрипты публикации

## 🤝 Вклад в документацию

При внесении изменений в проект:

1. Обновите соответствующие разделы документации
2. Добавьте примеры для новых функций
3. Обновите CHANGELOG.md
4. Проверьте актуальность всех ссылок
5. Обновите версию в документации

## 🔗 Полезные ссылки

- **PyPI**: https://pypi.org/project/onec-contract-generator/
- **GitHub**: https://github.com/onec-contract-generator/onec-contract-generator
- **Документация**: https://github.com/onec-contract-generator/onec-contract-generator#readme
- **Issues**: https://github.com/onec-contract-generator/onec-contract-generator/issues

---

**Удачной работы с документацией! 📚** 